*! version 5.0
* 13 August 2018
* NIDS
* Master Income do file for Nids Wave 2

* THIS IS 4th INCOME DO FILE - PERFORMING IMPUTATIONS FOR MISSING DATA: 4 OF 7
* THIS DO FILE PERFORMS IMPUTATIONS FOR MISSING DATA ON THE RELEVANT INCOME VARIABLES

*=====================================================================================================================================
* GLOBALS FOR DATA FILES, DO FILES AND VERSION SUFFIXES

* DEFINED IN "Master Income do file (1 of 7)"

version 12.0

*=====================================================================================================================================

********************
*IMPUTATION DO FILE*
********************

* OPENING DATASET PREPARED IN PRIOR DO FILE "Income - Preparing variables for imputation (4 of 7).DO"

set more off

use "$DataOUT\prepdata.dta", clear

*-------------------------------------------------------------------------------------------------------------------------------------

* DEFINING THE REGIMP STATA ROUTINE

cap program drop regimp
program define regimp
	gettoken depvar 0: 0
	local regressors "`0'"
	tempvar lndepvar
	gen `lndepvar'=ln(`depvar')
	xi:regress `lndepvar' `regressors'
	tempvar lndepvar_fit
	predict `lndepvar_fit'
	gen `depvar'_fit=exp(`lndepvar_fit')
	gen `depvar'_imp=`depvar'
	replace `depvar'_imp=`depvar'_fit if `depvar'==. & `depvar'_rec==1 & `depvar'_fit!=.
	gen `depvar'_data=0 if `depvar'_rec==1 & `depvar'!=.
	replace `depvar'_data=1 if `depvar'_rec==1 & `depvar'==. & `depvar'_fit!=.
	replace `depvar'_data=1 if `depvar'_rec==1 & `depvar'==. & `depvar'_imp!=.
	replace `depvar'_data=2 if `depvar'_rec==1 & `depvar'_imp==.
	label define `depvar'_data 0 "Survey" 1 "Imputed" 2 "Not imputed"
	label values `depvar'_data `depvar'_data
end

*----------------------------------------------------------------------------------------------------------------------------------------

mvdecode _all, mv(-3=.)

* RUNNING THE IMPUTATIONS

foreach var of varlist othe fwag cheq prof bonu extr cwag swag help ppen ///
uif comp indi inhe rnt retr brid gift loan sale remt plot opro {
	quietly count if `var'_d==1
		if r(N)>=100 {
			regimp `var' male race_d coloured asian_indian white w2_best_age_yrs age_d agesq tradeunion ///
schooling schoolingsq cert_nomat dip_nomat cert_mat dip_mat bachelors bach_dip honours postgrad ///
roster_married homerooms homeroomssq homerooms_d i.intmonth i.province i.geo2011
		quietly sum `var'_data
		if r(mean)>0.4 {
			replace `var'_imp=. if `var'_data==1
			lab def `var'_data 0 "Survey" 1 "Not imputed", modify
				}
		else {
				}
		}
				else {
					gen `var'_imp=`var'
					gen `var'_data=0 if `var'_rec==1
					replace `var'_data=1 if `var'_rec==1 & `var'_imp==.
					lab def `var'_data 0 "Survey" 1 "Not imputed", modify
					lab val `var'_data `var'_data
						}
			}


***************************************
*Imputations for State Old Age Pension*
***************************************

/*Respondents who do not give a figure for their old-age pension are assigned to the
maximum amount for the month before they were interviewed
Amount of the SOAP:
	- Before 1 April 2010: 1010
	- From 1 April 2010 to 1 April 2011: 1080
	- After 1 April 2011: 1140*/

*Imputation of income from state old age pension
gen spenhat=1080 if spen_rec==1 & int2010==1
replace spenhat=1080 if spen_rec==1 & (int2011==1 & intmonth>=13 & intmonth<=15)
replace spenhat=1140 if spen_rec==1 & (int2011==1 & intmonth>=16 & intmonth<=20)
gen spenimpute=1 if spenhat!=. & spen==.
replace spenimpute=0 if spenhat==. | spen!=.
replace spen=spenhat if spenimpute==1

*Imputation summary variable for state (RSA) old age pension
gen spen_flg=1 if spen_d==1
replace spen_flg=2 if spenimpute==1
label variable spen_flg "The old age state (RSA) pension data for this individual is:"
label define spen_flg 1 "Survey" 2 "Imputed" 3 "Not Imputed - Still Missing" 4 "Unit imputed"
label values spen_flg spen_flg

**********************************
*Imputations for disability grant*
**********************************

/*Respondents who do not give a figure for their disability grant are assigned to
maximum amount for the month before they were interviewed
Amount of the DG (same as for SOAP):
	- Before 1 April 2010: 1010
	- From 1 April 2010 to 1 April 2011: 1080
	- After 1 April 2011: 1140*/

*Imputation of income from disability grants
gen dishat=1080 if dis_rec==1 & int2010==1
replace dishat=1080 if dis_rec==1 & (int2011==1 & intmonth>=13 & intmonth<=15)
replace dishat=1140 if dis_rec==1 & (int2011==1 & intmonth>=16 & intmonth<=20)
gen disimpute=1 if dishat!=. & dis==.
replace disimpute=0 if dishat==. | dis!=.
replace dis=dishat if disimpute==1

*Imputation summary variable for disability grant
gen dis_flg=1 if dis_d==1
replace dis_flg=2 if disimpute==1
replace dis_flg=3 if dis==. & dis_rec==1
label variable dis_flg "The disability grant data for this individual is:"
label define dis_flg 1 "Survey" 2 "Imputed" 3 "Not imputed"
label values dis_flg dis_flg


*************************************
*Imputations for child support grant*
*************************************

/*Respondents who do not give a figure for their child support grant are assigned
the maximum amount for the month before they were interviewed, multiplied by the number
of biological children they have.
Amount of the CSG:
	- Before 1 April 2010: 240
	- From 1 April 2010 to 1 April 2011: 250
	- After 1 April 2011: 260*/

*Imputation of income from CSG
gen chldhat=250*biochildren if chld_rec==1 & int2010==1 & biochildren>0
replace chldhat=250*biochildren if chld_rec==1 & (int2011==1 & intmonth>=13 & intmonth<=15) & biochildren>0
replace chldhat=260*biochildren if chld_rec==1 & (int2011==1 & intmonth>=16 & intmonth<=20) & biochildren>0
gen chldimpute=1 if chldhat!=. & chld==.
replace chldimpute=0 if chldhat==. | chld!=.
replace chld=chldhat if chldimpute==1
replace chld_rec=0 if chld==. & biochildren==. & biochild==0 
*These people report no biological children and give no number for child grant.

*Imputation summary variable for CSG
gen chld_flg=1 if chld_d==1
replace chld_flg=2 if chldimpute==1
replace chld_flg=3 if chld==. & chld_rec==1
label variable chld_flg "The child support grant data for this individual is:"
label define chld_flg 1 "Survey" 2 "Imputed" 3 "Not Imputed" 
label values chld_flg chld_flg


***********************************
*Imputations for foster care grant*
***********************************

/*Respondents who do not give a figure for their foster child grant are assigned
the maximum amount for the month before they were interviewed.
Amount of the foster care grant:
	- Before 1 April 2010: 680
	- From 1 April 2010 to 1 April 2011: 710
	- After 1 April 2011: 740*/

*Imputation of income from foster care grants
gen fosthat=710 if fost_rec==1 & int2010==1
replace fosthat=740 if fost_rec==1 & (int2011==1 & intmonth>=13 & intmonth<=15)
replace fosthat=740 if fost_rec==1 & (int2011==1 & intmonth>=16 & intmonth<=20)
gen fostimpute=1 if fosthat!=. & fost==.
replace fostimpute=0 if fosthat==. | fost!=.
replace fost=fosthat if fostimpute==1

*Imputation summary variable for foster care grant
gen fost_flg=1 if fost_d==1
replace fost_flg=2 if fostimpute==1
replace fost_flg=3 if fost==. & fost_rec==1
label variable fost_flg "The foster care grant data for this individual is:"
label define fost_flg 1 "Survey" 2 "Imputed" 3 "Not imputed"
label values fost_flg fost_flg


***************************************
*Imputations for care dependency grant*
***************************************

/*Respondents who do not give a figure for their cape dependency grant are assigned
the maximum amount for the month before they were interviewed.
Amount of the care dependency grant (same as SOAP):
	- Before 1 April 2010: 1010
	- From 1 April 2010 to 1 April 2011: 1080
	- After 1 April 2011: 1140*/

*Imputation of income from care dependency grants
gen cdephat=1080 if cdep_rec==1 & int2010==1
replace cdephat=1140 if cdep_rec==1 & (int2011==1 & intmonth>=13 & intmonth<=15)
replace cdephat=1140 if cdep_rec==1 & (int2011==1 & intmonth>=16 & intmonth<=20)
gen cdepimpute=1 if cdephat!=. & cdep==.
replace cdepimpute=0 if cdephat==. | cdep!=.
replace cdep=cdephat if cdepimpute==1

*Imputation summary variable for care dependency grant
gen cdep_flg=1 if cdep_d==1
replace cdep_flg=2 if cdepimpute==1
replace cdep_flg=3 if cdep==. & cdep_rec==1
label variable cdep_flg "The care dependency grant data for this individual is:"
label define cdep_flg 1 "Survey" 2 "Imputed" 3 "Not imputed"
label values cdep_flg cdep_flg

***************************************
*Imputations household-level variables*
***************************************

*Imputations for one-shot income and imputed rental income from owner-occupied housing
sort w2_hhid
foreach var of varlist hhq_incb rent_would {
	replace `var'_d=. if w2_hhid==w2_hhid[_n-1]
	quietly count if `var'_d==1
		if r(N)>=100 {
			regimp `var' i.hometype i.homewalls i.homeroof homerooms i.hhrace hhrace_d ///
			hhedu hhedusq i.hhintmonth hhage hhage_d hhtu if w2_hhid!=w2_hhid[_n-1]
		quietly sum `var'_data
		if r(mean)>0.5 {
			replace `var'_imp=. if `var'_data==1
			lab def `var'_data 0 "Survey" 1 "Not imputed", modify
				}
		else {
				}
		}
				else {
					gen `var'_imp=`var'
					gen `var'_data=0 if `var'_rec==1
					replace `var'_data=1 if `var'_rec==1 & `var'_imp==.
					lab def `var'_data 0 "Survey" 1 "Not imputed", modify
					lab val `var'_data `var'_data
						}
			}
			

gen imprent=rent_would_imp

save "$DataOUT\impdata.dta", replace

* end of do fle 
*========================================================================================================================================

